@@ -17,7 +17,21 @@
 
 package org.apache.inlong.agent.plugin.sinks;
 
-import static org.apache.inlong.agent.constant.CommonConstants.DEFAULT_FIELD_SPLITTER;
+import org.apache.inlong.agent.common.AgentThreadFactory;
+import org.apache.inlong.agent.conf.JobProfile;
+import org.apache.inlong.agent.constant.CommonConstants;
+import org.apache.inlong.agent.core.task.MemoryManager;
+import org.apache.inlong.agent.message.BatchProxyMessage;
+import org.apache.inlong.agent.message.EndMessage;
+import org.apache.inlong.agent.message.PackProxyMessage;
+import org.apache.inlong.agent.message.ProxyMessage;
+import org.apache.inlong.agent.plugin.Message;
+import org.apache.inlong.agent.plugin.MessageFilter;
+import org.apache.inlong.agent.utils.AgentUtils;
+import org.apache.inlong.agent.utils.ThreadUtils;
+
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.nio.charset.StandardCharsets;
 import java.util.concurrent.ExecutorService;
@@ -27,19 +41,11 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 
-import org.apache.inlong.agent.common.AgentThreadFactory;
-import org.apache.inlong.agent.conf.JobProfile;
-import org.apache.inlong.agent.constant.CommonConstants;
-import org.apache.inlong.agent.message.BatchProxyMessage;
-import org.apache.inlong.agent.message.EndMessage;
-import org.apache.inlong.agent.message.PackProxyMessage;
-import org.apache.inlong.agent.message.ProxyMessage;
-import org.apache.inlong.agent.plugin.Message;
-import org.apache.inlong.agent.plugin.MessageFilter;
-import org.apache.inlong.agent.utils.AgentUtils;
-import org.apache.inlong.agent.utils.ThreadUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import static org.apache.inlong.agent.constant.CommonConstants.DEFAULT_FIELD_SPLITTER;
+import static org.apache.inlong.agent.constant.CommonConstants.DEFAULT_PROXY_PACKAGE_MAX_SIZE;
+import static org.apache.inlong.agent.constant.CommonConstants.PROXY_PACKAGE_MAX_SIZE;
+import static org.apache.inlong.agent.constant.FetcherConstants.AGENT_GLOBAL_CHANNEL_PERMIT;
+import static org.apache.inlong.agent.constant.FetcherConstants.AGENT_GLOBAL_WRITER_PERMIT;
 
 /**
  * sink message data to inlong-dataproxy
@@ -55,12 +61,16 @@ public class ProxySink extends AbstractSink {
     private SenderManager senderManager;
     private byte[] fieldSplitter;
     private volatile boolean shutdown = false;
+    private int maxPackSize;
 
     public ProxySink() {
     }
 
     @Override
     public void write(Message message) {
+        if (message == null) {
+            return;
+        }
         boolean suc = false;
         while (!suc) {
             suc = putInCache(message);
@@ -85,6 +95,13 @@ public class ProxySink extends AbstractSink {
             }
             AtomicBoolean suc = new AtomicBoolean(false);
             ProxyMessage proxyMessage = new ProxyMessage(message);
+            boolean writerPermitSuc = MemoryManager.getInstance()
+                    .tryAcquire(AGENT_GLOBAL_WRITER_PERMIT, message.getBody().length);
+            if (!writerPermitSuc) {
+                LOGGER.warn("writer tryAcquire failed");
+                MemoryManager.getInstance().printDetail(AGENT_GLOBAL_WRITER_PERMIT);
+                return false;
+            }
             // add proxy message to cache.
             cache.compute(proxyMessage.getBatchKey(),
                     (s, packProxyMessage) -> {
@@ -98,11 +115,11 @@ public class ProxySink extends AbstractSink {
                         return packProxyMessage;
                     });
             if (suc.get()) {
-                // semaphore should be acquired only when the message was put in cache successfully
-                senderManager.acquireSemaphore(1);
+                MemoryManager.getInstance().release(AGENT_GLOBAL_CHANNEL_PERMIT, message.getBody().length);
                 // increment the count of successful sinks
                 sinkMetric.sinkSuccessCount.incrementAndGet();
             } else {
+                MemoryManager.getInstance().release(AGENT_GLOBAL_WRITER_PERMIT, message.getBody().length);
                 // increment the count of failed sinks
                 sinkMetric.sinkFailCount.incrementAndGet();
             }
@@ -134,7 +151,7 @@ public class ProxySink extends AbstractSink {
      */
     private Runnable flushCache() {
         return () -> {
-            LOGGER.info("start flush cache thread for {} ProxySink", inlongGroupId);
+            LOGGER.info("start flush cache {}:{}", inlongGroupId, sourceName);
             while (!shutdown) {
                 try {
                     cache.forEach((batchKey, packProxyMessage) -> {
@@ -146,7 +163,6 @@ public class ProxySink extends AbstractSink {
                                     batchProxyMessage.getDataList().size(), jobInstanceId, sourceName,
                                     batchProxyMessage.getDataTime());
                         }
-
                     });
                 } catch (Exception ex) {
                     LOGGER.error("error caught", ex);
@@ -156,19 +172,20 @@ public class ProxySink extends AbstractSink {
                     AgentUtils.silenceSleepInMs(batchFlushInterval);
                 }
             }
+            LOGGER.info("stop flush cache {}:{}", inlongGroupId, sourceName);
         };
     }
 
     @Override
     public void init(JobProfile jobConf) {
         super.init(jobConf);
+        this.maxPackSize = jobConf.getInt(PROXY_PACKAGE_MAX_SIZE, DEFAULT_PROXY_PACKAGE_MAX_SIZE);
         messageFilter = initMessageFilter(jobConf);
         fieldSplitter = jobConf.get(CommonConstants.FIELD_SPLITTER, DEFAULT_FIELD_SPLITTER).getBytes(
                 StandardCharsets.UTF_8);
         executorService.execute(flushCache());
         senderManager = new SenderManager(jobConf, inlongGroupId, sourceName);
         try {
-            senderManager.addMessageSender();
             senderManager.Start();
         } catch (Throwable ex) {
             LOGGER.error("error while init sender for group id {}", inlongGroupId);
@@ -179,14 +196,15 @@ public class ProxySink extends AbstractSink {
 
     @Override
     public void destroy() {
-        LOGGER.info("destroy sink which sink from source name {}", sourceName);
+        LOGGER.info("destroy sink source name {}", sourceName);
         while (!sinkFinish()) {
-            LOGGER.info("job {} wait until cache all flushed to proxy", jobInstanceId);
+            LOGGER.info("sourceName {} wait until cache all flushed to proxy", sourceName);
             AgentUtils.silenceSleepInMs(batchFlushInterval);
         }
         shutdown = true;
         executorService.shutdown();
         senderManager.Stop();
+        LOGGER.info("destroy sink source name {} end", sourceName);
     }
 
     /**
