@@ -17,28 +17,6 @@
 
 package org.apache.inlong.agent.plugin.task;
 
-import static org.apache.inlong.agent.constant.JobConstants.JOB_FILE_META_ENV_LIST;
-import static org.apache.inlong.agent.constant.KubernetesConstants.KUBERNETES;
-import static org.apache.inlong.agent.constant.MetadataConstants.ENV_CVM;
-import static org.awaitility.Awaitility.await;
-import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.ArgumentMatchers.anyString;
-import static org.powermock.api.mockito.PowerMockito.mock;
-import static org.powermock.api.mockito.PowerMockito.when;
-import static org.powermock.api.mockito.PowerMockito.whenNew;
-import static org.powermock.api.support.membermodification.MemberMatcher.field;
-
-import com.google.gson.Gson;
-import java.io.File;
-import java.io.IOException;
-import java.nio.charset.StandardCharsets;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicLong;
-import java.util.stream.Collectors;
-import java.util.stream.IntStream;
 import org.apache.inlong.agent.conf.JobProfile;
 import org.apache.inlong.agent.constant.DataCollectType;
 import org.apache.inlong.agent.constant.JobConstants;
@@ -54,9 +32,12 @@ import org.apache.inlong.agent.plugin.channel.MemoryChannel;
 import org.apache.inlong.agent.plugin.sinks.MockSink;
 import org.apache.inlong.agent.plugin.sources.TextFileSource;
 import org.apache.inlong.agent.plugin.sources.reader.file.MonitorTextFile;
+import org.apache.inlong.agent.plugin.trigger.TestTriggerManager;
 import org.apache.inlong.agent.plugin.utils.TestUtils;
 import org.apache.inlong.common.metric.MetricItem;
 import org.apache.inlong.common.metric.MetricRegister;
+
+import com.google.gson.Gson;
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -68,12 +49,38 @@ import org.powermock.api.mockito.PowerMockito;
 import org.powermock.core.classloader.annotations.PowerMockIgnore;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import java.io.File;
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
+import java.util.Map;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
+import java.util.stream.Collectors;
+import java.util.stream.IntStream;
+
+import static org.apache.inlong.agent.constant.JobConstants.JOB_FILE_META_ENV_LIST;
+import static org.apache.inlong.agent.constant.KubernetesConstants.KUBERNETES;
+import static org.apache.inlong.agent.constant.MetadataConstants.ENV_CVM;
+import static org.awaitility.Awaitility.await;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.powermock.api.mockito.PowerMockito.mock;
+import static org.powermock.api.mockito.PowerMockito.when;
+import static org.powermock.api.mockito.PowerMockito.whenNew;
+import static org.powermock.api.support.membermodification.MemberMatcher.field;
 
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({TaskManager.class, MetricRegister.class})
-@PowerMockIgnore("javax.management.*")
+@PowerMockIgnore({"javax.management.*"})
 public class TestTextFileTask {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(TestTriggerManager.class);
     public static final TemporaryFolder TMP_FOLDER = new TemporaryFolder();
     private static final Gson GSON = new Gson();
     private static TaskManager taskManager;
@@ -87,10 +94,9 @@ public class TestTextFileTask {
     public static void setup() throws Exception {
         atomicLong = new AtomicLong(0L);
         atomicCountLong = new AtomicLong(0L);
-        taskCache = new ArrayList<>();
+        taskCache = Collections.synchronizedList(new ArrayList());
         TMP_FOLDER.create();
 
-        // mock metrics
         taskManager = new TaskManager(null);
         agentMetricItemSet = mock(AgentMetricItemSet.class);
         agentMetricItem = mock(AgentMetricItem.class);
@@ -104,29 +110,33 @@ public class TestTextFileTask {
     }
 
     @AfterClass
-    public static void teardown() {
+    public static void teardown() throws Exception {
         TMP_FOLDER.delete();
     }
 
     @After
     public void teardownEach() {
         taskCache.forEach(taskManager::removeTask);
-        taskCache.clear();
+        synchronized (taskCache) {
+            taskCache.clear();
+        }
     }
 
     public MockSink mockTextTask(JobProfile jobProfile) {
-        List<Reader> readers = new TextFileSource().split(jobProfile);
-        Channel channel = new MemoryChannel();
-        MockSink sink = new MockSink();
+        synchronized (this) {
+            List<Reader> readers = new TextFileSource().split(jobProfile);
+            Channel channel = new MemoryChannel();
+            MockSink sink = new MockSink();
 
-        readers.forEach(reader -> {
-            String taskId = String.format("Text file read %s", reader.getReadSource());
-            TaskWrapper taskWrapper =
-                    new TaskWrapper(taskManager, new Task(taskId, reader, sink, channel, jobProfile));
-            taskManager.submitTask(taskWrapper);
-            taskCache.add(taskId);
-        });
-        return sink;
+            readers.forEach(reader -> {
+                String taskId = String.format("Text file read %s", reader.getReadSource());
+                TaskWrapper taskWrapper =
+                        new TaskWrapper(taskManager, new Task(taskId, reader, sink, channel, jobProfile));
+                taskManager.submitTask(taskWrapper);
+                taskCache.add(taskId);
+            });
+            return sink;
+        }
     }
 
     /**
@@ -166,9 +176,11 @@ public class TestTextFileTask {
      */
     @Test
     public void testReadFull() throws IOException {
-        File file = TMP_FOLDER.newFile();
+        final TemporaryFolder temporaryFolder = new TemporaryFolder();
+        temporaryFolder.create();
+        File file = temporaryFolder.newFile();
         StringBuffer sb = new StringBuffer();
-        String testData1 = IntStream.range(0, 100)
+        String testData1 = IntStream.range(0, 5)
                 .mapToObj(String::valueOf)
                 .collect(Collectors.joining(System.lineSeparator()));
         sb.append(testData1);
@@ -184,21 +196,35 @@ public class TestTextFileTask {
         jobProfile.set(JOB_FILE_META_ENV_LIST, ENV_CVM);
         // mock data
         final MockSink sink = mockTextTask(jobProfile);
-        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 100);
+
+        LOGGER.info("sink getResult1 size: {}", sink.getResult().size());
+
+        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 5);
+
+        LOGGER.info("sink getResult2 size: {}", sink.getResult().size());
+
         await().atMost(10, TimeUnit.SECONDS).until(() -> MonitorTextFile.getInstance().monitorNum() == 1);
-        String testData = IntStream.range(100, 300)
+        String testData = IntStream.range(5, 10)
                 .mapToObj(String::valueOf)
                 .collect(Collectors.joining(System.lineSeparator()));
         sb.append(testData);
         sb.append(System.lineSeparator());
         TestUtils.write(file.getAbsolutePath(), sb);
 
-        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 100);
-        String collectData = sink.getResult().stream().map(message -> {
-            String content = new String(message.getBody(), StandardCharsets.UTF_8);
-            Map<String, String> logJson = GSON.fromJson(content, Map.class);
-            return logJson.get(MetadataConstants.DATA_CONTENT);
-        }).collect(Collectors.joining(System.lineSeparator()));
+        LOGGER.info("sink getResult3 size: {}", sink.getResult().size());
+
+        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() >= 5);
+
+        LOGGER.info("sink getResult4 size: {}", sink.getResult().size());
+
+        synchronized (this) {
+            String collectData = sink.getResult().stream().map(message -> {
+                String content = new String(message.getBody(), StandardCharsets.UTF_8);
+                Map<String, String> logJson = GSON.fromJson(content, Map.class);
+                return logJson.get(MetadataConstants.DATA_CONTENT);
+            }).collect(Collectors.joining(System.lineSeparator()));
+        }
+        temporaryFolder.delete();
     }
 
     /**
@@ -206,9 +232,11 @@ public class TestTextFileTask {
      */
     @Test
     public void testReadIncrement() throws IOException {
-        File file = TMP_FOLDER.newFile();
+        final TemporaryFolder temporaryFolder = new TemporaryFolder();
+        temporaryFolder.create();
+        File file = temporaryFolder.newFile();
         StringBuffer sb = new StringBuffer();
-        sb.append(IntStream.range(0, 100)
+        sb.append(IntStream.range(0, 5)
                 .mapToObj(String::valueOf)
                 .collect(Collectors.joining(System.lineSeparator())));
         sb.append(System.lineSeparator());
@@ -225,26 +253,31 @@ public class TestTextFileTask {
         // mock data
         final MockSink sink = mockTextTask(jobProfile);
         await().atMost(10, TimeUnit.SECONDS).until(() -> MonitorTextFile.getInstance().monitorNum() == 1);
-        String testData = IntStream.range(100, 300)
+        String testData = IntStream.range(5, 10)
                 .mapToObj(String::valueOf)
                 .collect(Collectors.joining(System.lineSeparator()));
         sb.append(testData);
         sb.append(System.lineSeparator());
         TestUtils.write(file.getAbsolutePath(), sb);
 
-        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 300);
-        String collectData = sink.getResult().stream().map(message -> {
-            String content = new String(message.getBody(), StandardCharsets.UTF_8);
-            Map<String, String> logJson = GSON.fromJson(content, Map.class);
-            return logJson.get(MetadataConstants.DATA_CONTENT);
-        }).collect(Collectors.joining(System.lineSeparator()));
+        await().atMost(10, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 10);
+        synchronized (this) {
+            String collectData = sink.getResult().stream().map(message -> {
+                String content = new String(message.getBody(), StandardCharsets.UTF_8);
+                Map<String, String> logJson = GSON.fromJson(content, Map.class);
+                return logJson.get(MetadataConstants.DATA_CONTENT);
+            }).collect(Collectors.joining(System.lineSeparator()));
+        }
+        temporaryFolder.delete();
     }
 
     @Test
     public void testScaleData() throws IOException {
-        File file = TMP_FOLDER.newFile();
+        final TemporaryFolder temporaryFolder = new TemporaryFolder();
+        temporaryFolder.create();
+        File file = temporaryFolder.newFile();
         StringBuffer sb = new StringBuffer();
-        String testData1 = IntStream.range(0, 100)
+        String testData1 = IntStream.range(0, 5)
                 .mapToObj(String::valueOf)
                 .collect(Collectors.joining(System.lineSeparator()));
         sb.append(testData1);
@@ -258,6 +291,7 @@ public class TestTextFileTask {
         jobProfile.set(JobConstants.JOB_FILE_CONTENT_COLLECT_TYPE, DataCollectType.FULL);
         // mock data
         final MockSink sink = mockTextTask(jobProfile);
-        await().atMost(100, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 100);
+        await().atMost(100, TimeUnit.SECONDS).until(() -> sink.getResult().size() == 5);
+        temporaryFolder.delete();
     }
 }
