@@ -97,6 +97,24 @@ const conf: RouteProps[] = [
     path: '/node',
     component: () => import('@/ui/pages/Nodes'),
   },
+  {
+    path: '/sync',
+    component: () => import('@/ui/pages/SynchronizeDashboard'),
+    childRoutes: [
+      {
+        path: '/create/:id?',
+        component: () => import('@/ui/pages/SynchronizeDetail'),
+      },
+      {
+        path: '/detail/:id',
+        component: () => import('@/ui/pages/SynchronizeDetail'),
+      },
+    ],
+  },
+  {
+    path: '/tenant',
+    component: () => import('@/ui/pages/TenantManagement'),
+  },
   {
     component: () => import('@/ui/pages/Error/404'),
   },
