@@ -26,7 +26,7 @@ const resources = {
   en: {
     translation: {
       'configs.menus.Process': 'Approval',
-      'configs.menus.Groups': 'Integration',
+      'configs.menus.Groups': 'Ingestion',
       'configs.menus.Subscribe': 'Subscription',
       'configs.menus.Clusters': 'Clusters',
       'configs.menus.ClusterTags': 'ClusterTags',
@@ -34,12 +34,14 @@ const resources = {
       'configs.menus.UserManagement': 'User Management',
       'configs.menus.ProcessManagement': 'Process Management',
       'configs.menus.Nodes': 'DataNodes',
+      'configs.menus.DataSynchronize': 'Synchronization',
+      'configs.menus.TenantManagement': 'Tenant Management',
     },
   },
   cn: {
     translation: {
       'configs.menus.Process': '审批管理',
-      'configs.menus.Groups': '数据集成',
+      'configs.menus.Groups': '数据接入',
       'configs.menus.Subscribe': '数据订阅',
       'configs.menus.Clusters': '集群管理',
       'configs.menus.ClusterTags': '标签管理',
@@ -47,6 +49,8 @@ const resources = {
       'configs.menus.UserManagement': '用户管理',
       'configs.menus.ProcessManagement': '流程管理',
       'configs.menus.Nodes': '数据节点',
+      'configs.menus.DataSynchronize': '数据同步',
+      'configs.menus.TenantManagement': '租户管理',
     },
   },
 };
