@@ -17,18 +17,20 @@
 
 package org.apache.inlong.dataproxy.sink.common;
 
-import java.util.Map;
-import org.apache.flume.Event;
+import org.apache.inlong.common.enums.DataProxyMsgEncType;
 import org.apache.inlong.common.msg.AttributeConstants;
 import org.apache.inlong.dataproxy.config.pojo.MQClusterConfig;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
 import org.apache.inlong.dataproxy.utils.Constants;
 import org.apache.inlong.dataproxy.utils.DateTimeUtils;
-import org.apache.inlong.dataproxy.utils.InLongMsgVer;
 import org.apache.inlong.dataproxy.utils.MessageUtils;
 import org.apache.inlong.tubemq.client.config.TubeClientConfig;
 import org.apache.inlong.tubemq.corebase.Message;
 
+import org.apache.flume.Event;
+
+import java.util.Map;
+
 public class TubeUtils {
 
     /**
@@ -60,14 +62,13 @@ public class TubeUtils {
         Map<String, String> headers = event.getHeaders();
         Message message = new Message(topicName, event.getBody());
         String pkgVersion = headers.get(ConfigConstants.MSG_ENCODE_VER);
-        if (InLongMsgVer.INLONG_V1.getName().equalsIgnoreCase(pkgVersion)) {
+        if (DataProxyMsgEncType.MSG_ENCODE_TYPE_PB.getStrId().equalsIgnoreCase(pkgVersion)) {
             long dataTimeL = Long.parseLong(headers.get(ConfigConstants.PKG_TIME_KEY));
             message.putSystemHeader(headers.get(Constants.INLONG_STREAM_ID),
                     DateTimeUtils.ms2yyyyMMddHHmm(dataTimeL));
         } else {
-            long dataTimeL = Long.parseLong(headers.get(AttributeConstants.DATA_TIME));
             message.putSystemHeader(headers.get(AttributeConstants.STREAM_ID),
-                    DateTimeUtils.ms2yyyyMMddHHmm(dataTimeL));
+                    headers.get(ConfigConstants.PKG_TIME_KEY));
         }
         Map<String, String> extraAttrMap = MessageUtils.getXfsAttrs(headers, pkgVersion);
         for (Map.Entry<String, String> entry : extraAttrMap.entrySet()) {
