@@ -33,5 +33,7 @@ public class DataNodeType {
     public static final String REDIS = "REDIS";
     public static final String KUDU = "KUDU";
     public static final String POSTGRESQL = "POSTGRESQL";
-
+    public static final String ORACLE = "ORACLE";
+    public static final String SQLSERVER = "SQLSERVER";
+    public static final String MONGODB = "MONGODB";
 }
