@@ -17,21 +17,24 @@
 
 package org.apache.inlong.manager.dao.mapper;
 
-import org.apache.ibatis.annotations.Options;
-import org.apache.ibatis.annotations.Param;
-import org.apache.ibatis.cursor.Cursor;
-import org.apache.ibatis.mapping.ResultSetType;
+import org.apache.inlong.manager.common.tenant.MultiTenantQuery;
 import org.apache.inlong.manager.dao.entity.InlongGroupEntity;
 import org.apache.inlong.manager.pojo.group.InlongGroupBriefInfo;
 import org.apache.inlong.manager.pojo.group.InlongGroupPageRequest;
 import org.apache.inlong.manager.pojo.group.InlongGroupTopicRequest;
 import org.apache.inlong.manager.pojo.sort.standalone.SortSourceGroupInfo;
+
+import org.apache.ibatis.annotations.Options;
+import org.apache.ibatis.annotations.Param;
+import org.apache.ibatis.cursor.Cursor;
+import org.apache.ibatis.mapping.ResultSetType;
 import org.springframework.stereotype.Repository;
 
 import java.util.Date;
 import java.util.List;
 import java.util.Map;
 
+@MultiTenantQuery
 @Repository
 public interface InlongGroupEntityMapper {
 
@@ -40,7 +43,7 @@ public interface InlongGroupEntityMapper {
     InlongGroupEntity selectByPrimaryKey(Integer id);
 
     List<Map<String, Object>> countGroupByUser(@Param(value = "username") String username,
-            @Param(value = "lightweight") Integer lightweight);
+            @Param(value = "inlongGroupMode") Integer inlongGroupMode);
 
     InlongGroupEntity selectByGroupId(String groupId);
 
@@ -59,6 +62,7 @@ public interface InlongGroupEntityMapper {
      *
      * @return All inlong group info.
      */
+    @MultiTenantQuery(with = false)
     @Options(resultSetType = ResultSetType.FORWARD_ONLY, fetchSize = Integer.MIN_VALUE)
     Cursor<SortSourceGroupInfo> selectAllGroups();
 
