@@ -17,12 +17,12 @@
 
 package org.apache.inlong.manager.pojo.cluster;
 
+import org.apache.inlong.manager.common.validation.SaveValidation;
+import org.apache.inlong.manager.common.validation.UpdateValidation;
+
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.Data;
-
-import org.apache.inlong.manager.common.validation.SaveValidation;
-import org.apache.inlong.manager.common.validation.UpdateValidation;
 import org.hibernate.validator.constraints.Length;
 
 import javax.validation.constraints.NotBlank;
@@ -54,6 +54,10 @@ public class ClusterTagRequest {
     @Length(max = 256, message = "length must be less than or equal to 256")
     private String description;
 
+    @ApiModelProperty(value = "Inlong tenant of cluster tag", hidden = true)
+    @Length(max = 256, message = "length must be less than or equal to 256")
+    private String tenant;
+
     @ApiModelProperty(value = "Name of in charges, separated by commas")
     @Length(max = 512, message = "length must be less than or equal to 512")
     private String inCharges;
