@@ -83,9 +83,9 @@ public interface DataNodeOperator {
      * Update related stream source.
      *
      * @param request data node request
-     * @param entity data node entity
+     * @param oldEntity old data node entity
      * @param operator operator
      */
-    void updateRelatedStreamSource(DataNodeRequest request, DataNodeEntity entity, String operator);
+    void updateRelatedStreamSource(DataNodeRequest request, DataNodeEntity oldEntity, String operator);
 
 }
