@@ -35,10 +35,11 @@ CREATE TABLE IF NOT EXISTS `inlong_group`
     `max_length`             int(11)               DEFAULT '10240' COMMENT 'The maximum length of a single piece of data, unit: Byte',
     `enable_zookeeper`       tinyint(1)            DEFAULT '0' COMMENT 'Whether to enable the zookeeper, 0-disable, 1-enable',
     `enable_create_resource` tinyint(1)            DEFAULT '1' COMMENT 'Whether to enable create resource? 0-disable, 1-enable',
-    `lightweight`            tinyint(1)            DEFAULT '0' COMMENT 'Whether to use lightweight mode, 0-no, 1-yes',
+    `inlong_group_mode`      tinyint(1)            DEFAULT '0' COMMENT 'InLong group mode, Standard mode(include Data Ingestion and Synchronization): 0, DataSync mode(only Data Synchronization): 1',
     `data_report_type`       int(4)                DEFAULT '0' COMMENT 'Data report type. 0: report to DataProxy and respond when the DataProxy received data. 1: report to DataProxy and respond after DataProxy sends data. 2: report to MQ and respond when the MQ received data',
     `inlong_cluster_tag`     varchar(128)          DEFAULT NULL COMMENT 'The cluster tag, which links to inlong_cluster table',
     `ext_params`             mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
+    `tenant`                 varchar(256)          DEFAULT 'public' COMMENT 'Inlong tenant of the inlong group',
     `in_charges`             varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
     `followers`              varchar(512)          DEFAULT NULL COMMENT 'Name of followers, separated by commas',
     `status`                 int(4)                DEFAULT '100' COMMENT 'Inlong group status',
@@ -68,8 +69,7 @@ CREATE TABLE IF NOT EXISTS `inlong_group_ext`
     `is_deleted`      int(11)           DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
     `modify_time`     timestamp    NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
     PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_inlong_group_key` (`inlong_group_id`, `key_name`),
-    INDEX `group_ext_group_index` (`inlong_group_id`)
+    UNIQUE KEY `unique_inlong_group_key` (`inlong_group_id`, `key_name`)
 );
 
 -- ----------------------------
@@ -81,6 +81,7 @@ CREATE TABLE IF NOT EXISTS `inlong_cluster_tag`
     `cluster_tag` varchar(128) NOT NULL COMMENT 'Cluster tag',
     `ext_params`  mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
     `description` varchar(256)          DEFAULT '' COMMENT 'Description of cluster tag',
+    `tenant`      varchar(256)          DEFAULT 'public' COMMENT 'Inlong tenant of the inlong cluster tag',
     `in_charges`  varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
     `status`      int(4)                DEFAULT '0' COMMENT 'Cluster status',
     `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
@@ -98,24 +99,26 @@ CREATE TABLE IF NOT EXISTS `inlong_cluster_tag`
 -- ----------------------------
 CREATE TABLE IF NOT EXISTS `inlong_cluster`
 (
-    `id`           int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
-    `name`         varchar(128) NOT NULL COMMENT 'Cluster name',
-    `type`         varchar(20)           DEFAULT '' COMMENT 'Cluster type, such as: TUBEMQ, PULSAR, DATAPROXY, etc',
-    `url`          varchar(512)          DEFAULT NULL COMMENT 'Cluster URL',
-    `cluster_tags` varchar(512)          DEFAULT NULL COMMENT 'Cluster tag, separated by commas',
-    `ext_tag`      varchar(128)          DEFAULT NULL COMMENT 'Extension tag, for extended use',
-    `token`        varchar(512)          DEFAULT NULL COMMENT 'Cluster token',
-    `ext_params`   mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
-    `description`  varchar(256)          DEFAULT '' COMMENT 'Description of cluster',
-    `heartbeat`    mediumtext            DEFAULT NULL COMMENT 'Cluster heartbeat info',
-    `in_charges`   varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
-    `status`       int(4)                DEFAULT '0' COMMENT 'Cluster status',
-    `is_deleted`   int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
-    `creator`      varchar(64)  NOT NULL COMMENT 'Creator name',
-    `modifier`     varchar(64)           DEFAULT NULL COMMENT 'Modifier name',
-    `create_time`  timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
-    `modify_time`  timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
-    `version`      int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    `id`                    int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `name`                  varchar(128) NOT NULL COMMENT 'Cluster name',
+    `display_name`          varchar(128)          DEFAULT NULL COMMENT 'Cluster display name',
+    `type`                  varchar(20)           DEFAULT '' COMMENT 'Cluster type, such as: TUBEMQ, PULSAR, DATAPROXY, etc',
+    `url`                   varchar(512)          DEFAULT NULL COMMENT 'Cluster URL',
+    `cluster_tags`          varchar(512)          DEFAULT NULL COMMENT 'Cluster tag, separated by commas',
+    `ext_tag`               varchar(128)          DEFAULT NULL COMMENT 'Extension tag, for extended use',
+    `token`                 varchar(512)          DEFAULT NULL COMMENT 'Cluster token',
+    `ext_params`            mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
+    `description`           varchar(256)          DEFAULT '' COMMENT 'Description of cluster',
+    `heartbeat`             mediumtext            DEFAULT NULL COMMENT 'Cluster heartbeat info',
+    `tenant`                varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of cluster',
+    `in_charges`            varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
+    `status`                int(4)                DEFAULT '0' COMMENT 'Cluster status',
+    `is_deleted`            int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
+    `creator`               varchar(64)  NOT NULL COMMENT 'Creator name',
+    `modifier`              varchar(64)           DEFAULT NULL COMMENT 'Modifier name',
+    `create_time`           timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time`           timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`               int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
     PRIMARY KEY (`id`),
     UNIQUE KEY `unique_inlong_cluster` (`name`, `type`, `is_deleted`),
     INDEX `cluster_type_index` (`type`)
@@ -160,6 +163,7 @@ CREATE TABLE IF NOT EXISTS `inlong_consume`
     `filter_enabled`   int(2)                DEFAULT '0' COMMENT 'Whether to filter consume, 0: not filter, 1: filter',
     `inlong_stream_id` varchar(256)          DEFAULT NULL COMMENT 'The target inlong stream id of this consume, needed if the filter_enabled=1',
     `ext_params`       mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
+    `tenant`           varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of the inlong consume',
     `in_charges`       varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
     `status`           int(4)                DEFAULT '100' COMMENT 'Inlong consume status',
     `previous_status`  int(4)                DEFAULT '100' COMMENT 'Previous status',
@@ -179,24 +183,27 @@ CREATE TABLE IF NOT EXISTS `inlong_consume`
 -- ----------------------------
 CREATE TABLE IF NOT EXISTS `data_node`
 (
-    `id`          int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
-    `name`        varchar(128) NOT NULL COMMENT 'Node name',
-    `type`        varchar(20)           DEFAULT '' COMMENT 'Node type, such as: MYSQL, HIVE, KAFKA, ES, etc',
-    `url`         varchar(512)          DEFAULT NULL COMMENT 'Node URL',
-    `username`    varchar(128)          DEFAULT NULL COMMENT 'Username for node if needed',
-    `token`       varchar(512)          DEFAULT NULL COMMENT 'Node token',
-    `ext_params`  mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
-    `description` varchar(256)          DEFAULT '' COMMENT 'Description of data node',
-    `in_charges`  varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
-    `status`      int(4)                DEFAULT '0' COMMENT 'Node status',
-    `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
-    `creator`     varchar(64)  NOT NULL COMMENT 'Creator name',
-    `modifier`    varchar(64)           DEFAULT NULL COMMENT 'Modifier name',
-    `create_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
-    `modify_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
-    `version`     int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    `id`                      int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
+    `name`                    varchar(128) NOT NULL COMMENT 'Node name',
+    `display_name`            varchar(128)          DEFAULT NULL COMMENT 'Data node display name',
+    `type`                    varchar(20)           DEFAULT '' COMMENT 'Node type, such as: MYSQL, HIVE, KAFKA, ES, etc',
+    `url`                     varchar(512)          DEFAULT NULL COMMENT 'Node URL',
+    `username`                varchar(128)          DEFAULT NULL COMMENT 'Username for node if needed',
+    `token`                   varchar(512)          DEFAULT NULL COMMENT 'Node token',
+    `ext_params`              mediumtext            DEFAULT NULL COMMENT 'Extended params, will be saved as JSON string',
+    `description`             varchar(256)          DEFAULT '' COMMENT 'Description of data node',
+    `tenant`                  varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of the data node',
+    `in_charges`              varchar(512) NOT NULL COMMENT 'Name of responsible person, separated by commas',
+    `status`                  int(4)                DEFAULT '0' COMMENT 'Node status',
+    `is_deleted`              int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
+    `creator`                 varchar(64)  NOT NULL COMMENT 'Creator name',
+    `modifier`                varchar(64)           DEFAULT NULL COMMENT 'Modifier name',
+    `create_time`             timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time`             timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`                 int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
     PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_data_node` (`name`, `type`, `is_deleted`)
+    UNIQUE KEY `unique_data_node` (`name`, `type`, `is_deleted`),
+    INDEX `datanode_tenant_index` (`tenant`, `is_deleted`)
 );
 
 -- ----------------------------
@@ -247,8 +254,7 @@ CREATE TABLE IF NOT EXISTS `inlong_stream`
     `modify_time`      timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
     `version`          int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
     PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_inlong_stream` (`inlong_stream_id`, `inlong_group_id`, `is_deleted`),
-    INDEX `stream_group_id_index` (`inlong_group_id`)
+    UNIQUE KEY `unique_inlong_stream` (`inlong_group_id`, `inlong_stream_id`, `is_deleted`)
 );
 
 -- ----------------------------
@@ -264,8 +270,7 @@ CREATE TABLE IF NOT EXISTS `inlong_stream_ext`
     `is_deleted`       int(11)           DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
     `modify_time`      timestamp    NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
     PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_inlong_stream_key` (`inlong_group_id`, `inlong_stream_id`, `key_name`),
-    INDEX `stream_id_index` (`inlong_group_id`, `inlong_stream_id`)
+    UNIQUE KEY `unique_inlong_stream_key` (`inlong_group_id`, `inlong_stream_id`, `key_name`)
 );
 
 -- ----------------------------
@@ -530,12 +535,33 @@ CREATE TABLE IF NOT EXISTS `role`
 );
 
 -- ----------------------------
--- Table structure for user_role
+-- Table structure for tenant user_role
 -- ----------------------------
-CREATE TABLE IF NOT EXISTS `user_role`
+CREATE TABLE IF NOT EXISTS `tenant_user_role`
 (
     `id`          int(11)      NOT NULL AUTO_INCREMENT,
-    `user_name`   varchar(256) NOT NULL COMMENT 'Username',
+    `username`   varchar(256)  NOT NULL COMMENT 'Username',
+    `role_code`   varchar(256) NOT NULL COMMENT 'User role code',
+    `disabled`    tinyint(1)   NOT NULL DEFAULT '0' COMMENT 'Whether to disabled, 0: enabled, 1: disabled',
+    `tenant`      varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant',
+    `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0 is not deleted, if greater than 0, delete',
+    `creator`     varchar(256) NOT NULL COMMENT 'Creator name',
+    `modifier`    varchar(256)          DEFAULT NULL COMMENT 'Modifier name',
+    `create_time` datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time` datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`     int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_tenant_user` (`username`, `tenant`, `is_deleted`),
+    INDEX `index_tenant` (`tenant`, `is_deleted`)
+);
+
+-- ----------------------------
+-- Table structure for inlong_user_role
+-- ----------------------------
+CREATE TABLE IF NOT EXISTS `inlong_user_role`
+(
+    `id`          int(11)      NOT NULL AUTO_INCREMENT,
+    `username`   varchar(256)  NOT NULL COMMENT 'Username',
     `role_code`   varchar(256) NOT NULL COMMENT 'User role code',
     `disabled`    tinyint(1)   NOT NULL DEFAULT '0' COMMENT 'Whether to disabled, 0: enabled, 1: disabled',
     `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0 is not deleted, if greater than 0, delete',
@@ -544,9 +570,13 @@ CREATE TABLE IF NOT EXISTS `user_role`
     `create_time` datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
     `modify_time` datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
     `version`     int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
-    PRIMARY KEY (`id`)
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_inlong_user_role` (`username`, `role_code`, `is_deleted`)
 );
 
+INSERT INTO `inlong_user_role` (`username`, `role_code`, `creator`)
+VALUES ('admin', 'INLONG_ADMIN', 'inlong_init');
+
 -- ----------------------------
 -- Table structure for workflow_approver
 -- ----------------------------
@@ -555,6 +585,7 @@ CREATE TABLE IF NOT EXISTS `workflow_approver`
     `id`           int(11)       NOT NULL AUTO_INCREMENT,
     `process_name` varchar(256)  NOT NULL COMMENT 'Process name',
     `task_name`    varchar(256)  NOT NULL COMMENT 'Approval task name',
+    `tenant`       varchar(256)  NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of workflow approver',
     `approvers`    varchar(1024) NOT NULL COMMENT 'Approvers, separated by commas',
     `creator`      varchar(64)   NOT NULL COMMENT 'Creator name',
     `modifier`     varchar(64)            DEFAULT NULL COMMENT 'Modifier name',
@@ -567,9 +598,9 @@ CREATE TABLE IF NOT EXISTS `workflow_approver`
 );
 
 -- create workflow approver for newly inlong group and inlong consume.
-INSERT INTO `workflow_approver`(`process_name`, `task_name`, `approvers`, `creator`, `modifier`)
-VALUES ('APPLY_GROUP_PROCESS', 'ut_admin', 'admin', 'inlong_init', 'inlong_init'),
-       ('APPLY_CONSUME_PROCESS', 'ut_admin', 'admin', 'inlong_init', 'inlong_init');
+INSERT INTO `workflow_approver`(`process_name`, `task_name`, `tenant`, `approvers`, `creator`, `modifier`)
+VALUES ('APPLY_GROUP_PROCESS', 'ut_admin', 'public', 'admin', 'inlong_init', 'inlong_init'),
+       ('APPLY_CONSUME_PROCESS', 'ut_admin', 'public', 'admin', 'inlong_init', 'inlong_init');
 
 -- ----------------------------
 -- Table structure for workflow_event_log
@@ -611,6 +642,7 @@ CREATE TABLE IF NOT EXISTS `workflow_process`
     `title`            varchar(256)          DEFAULT NULL COMMENT 'Process title',
     `inlong_group_id`  varchar(256)          DEFAULT NULL COMMENT 'Inlong group id to which this process belongs',
     `inlong_stream_id` varchar(256)          DEFAULT NULL COMMENT 'Inlong stream id to which this process belongs',
+    `tenant`           varchar(256) NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of workflow process',
     `applicant`        varchar(256) NOT NULL COMMENT 'Applicant',
     `status`           varchar(64)  NOT NULL COMMENT 'Status',
     `form_data`        mediumtext COMMENT 'Form information',
@@ -634,6 +666,7 @@ CREATE TABLE IF NOT EXISTS `workflow_task`
     `process_display_name` varchar(256)  NOT NULL COMMENT 'Process name',
     `name`                 varchar(256)  NOT NULL COMMENT 'Task name',
     `display_name`         varchar(256)  NOT NULL COMMENT 'Task display name',
+    `tenant`               varchar(256)  NOT NULL DEFAULT 'public' COMMENT 'Inlong tenant of workflow task',
     `applicant`            varchar(64)   DEFAULT NULL COMMENT 'Applicant',
     `approvers`            varchar(1024) NOT NULL COMMENT 'Approvers',
     `status`               varchar(64)   NOT NULL COMMENT 'Status',
@@ -697,7 +730,6 @@ CREATE TABLE IF NOT EXISTS `sort_source_config`
 -- ----------------------------
 CREATE TABLE IF NOT EXISTS `component_heartbeat`
 (
-    `id`               int(11)     NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
     `component`        varchar(64) NOT NULL DEFAULT '' COMMENT 'Component name, such as: Agent, Sort...',
     `instance`         varchar(64) NOT NULL DEFAULT '' COMMENT 'Component instance, can be ip, name...',
     `status_heartbeat` mediumtext           DEFAULT NULL COMMENT 'Status heartbeat info',
@@ -705,8 +737,7 @@ CREATE TABLE IF NOT EXISTS `component_heartbeat`
     `report_time`      bigint(20)  NOT NULL COMMENT 'Report time',
     `create_time`      timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
     `modify_time`      timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
-    PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_component_heartbeat` (`component`, `instance`)
+    PRIMARY KEY (`component`, `instance`)
 );
 
 -- ----------------------------
@@ -714,7 +745,6 @@ CREATE TABLE IF NOT EXISTS `component_heartbeat`
 -- ----------------------------
 CREATE TABLE IF NOT EXISTS `group_heartbeat`
 (
-    `id`               int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
     `component`        varchar(64)  NOT NULL DEFAULT '' COMMENT 'Component name, such as: Agent, Sort...',
     `instance`         varchar(64)  NOT NULL DEFAULT '' COMMENT 'Component instance, can be ip, name...',
     `inlong_group_id`  varchar(256) NOT NULL DEFAULT '' COMMENT 'Owning inlong group id',
@@ -723,8 +753,7 @@ CREATE TABLE IF NOT EXISTS `group_heartbeat`
     `report_time`      bigint(20)   NOT NULL COMMENT 'Report time',
     `create_time`      timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
     `modify_time`      timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
-    PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_group_heartbeat` (`component`, `instance`, `inlong_group_id`)
+    PRIMARY KEY (`component`, `instance`, `inlong_group_id`)
 );
 
 -- ----------------------------
@@ -732,7 +761,6 @@ CREATE TABLE IF NOT EXISTS `group_heartbeat`
 -- ----------------------------
 CREATE TABLE IF NOT EXISTS `stream_heartbeat`
 (
-    `id`               int(11)      NOT NULL AUTO_INCREMENT COMMENT 'Incremental primary key',
     `component`        varchar(64)  NOT NULL DEFAULT '' COMMENT 'Component name, such as: Agent, Sort...',
     `instance`         varchar(64)  NOT NULL DEFAULT '' COMMENT 'Component instance, can be ip, name...',
     `inlong_group_id`  varchar(256) NOT NULL DEFAULT '' COMMENT 'Owning inlong group id',
@@ -742,9 +770,34 @@ CREATE TABLE IF NOT EXISTS `stream_heartbeat`
     `report_time`      bigint(20)   NOT NULL COMMENT 'Report time',
     `create_time`      timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
     `modify_time`      timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
-    PRIMARY KEY (`id`),
-    UNIQUE KEY `unique_stream_heartbeat` (`component`, `instance`, `inlong_group_id`, `inlong_stream_id`)
+    PRIMARY KEY (`component`, `instance`, `inlong_group_id`, `inlong_stream_id`)
 );
+
+-- ----------------------------
+-- Table structure for inlong_tenant
+-- ----------------------------
+CREATE TABLE IF NOT EXISTS `inlong_tenant`
+(
+    `id`           int(11)      NOT NULL AUTO_INCREMENT,
+    `name`         varchar(256) NOT NULL COMMENT 'Namespace, not support modification',
+    `description`  varchar(256) DEFAULT '' COMMENT 'Description of tenant',
+    `is_deleted`   int(11)      DEFAULT '0' COMMENT 'Whether to delete, 0 is not deleted, if greater than 0, delete',
+    `creator`      varchar(256) NOT NULL COMMENT 'Creator name',
+    `modifier`     varchar(256) DEFAULT NULL COMMENT 'Modifier name',
+    `create_time`  datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time`  datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`      int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_tenant_key` (`name`, `is_deleted`)
+);
+
+-- ----------------------------
+-- Insert inlong_tenant item
+-- ----------------------------
+INSERT INTO `inlong_tenant`(`name`, `description`, `creator`, `modifier`)
+VALUES ('public', 'Default tenant', 'admin', 'admin'),
+       ('another', 'Another tenant', 'admin', 'admin');
+
 -- ----------------------------
 -- Table structure for audit_base
 -- ----------------------------
@@ -789,7 +842,32 @@ VALUES ('audit_sdk_collect', 'SDK', 0, '1'),
        ('audit_sort_mysql_input', 'MYSQL', 0, '23'),
        ('audit_sort_mysql_output', 'MYSQL', 1, '24'),
        ('audit_sort_kudu_input', 'KUDU', 0, '25'),
-       ('audit_sort_kudu_output', 'KUDU', 1, '26');
+       ('audit_sort_kudu_output', 'KUDU', 1, '26'),
+       ('audit_sort_postgres_input', 'POSTGRESQL', 0, '27'),
+       ('audit_sort_postgres_output', 'POSTGRESQL', 1, '28');
+
+-- ----------------------------
+-- Table structure for audit_source
+-- ----------------------------
+CREATE TABLE IF NOT EXISTS `audit_source`
+(
+    `id`          int(11)      NOT NULL AUTO_INCREMENT,
+    `name`        varchar(128) NOT NULL COMMENT 'Audit source name',
+    `type`        varchar(20)  NOT NULL COMMENT 'Audit source type, including: MYSQL, CLICKHOUSE, ELASTICSEARCH',
+    `url`         varchar(256) NOT NULL COMMENT 'Audit source URL, for MYSQL or CLICKHOUSE, is jdbcUrl, and for ELASTICSEARCH is the access URL with hostname:port',
+    `enable_auth` tinyint(1)            DEFAULT '1' COMMENT 'Enable auth or not, 0: disable, 1: enable',
+    `username`    varchar(128)          COMMENT 'Audit source username, needed if auth_enable is 1' ,
+    `token`       varchar(512)          DEFAULT NULL COMMENT 'Audit source token, needed if auth_enable is 1',
+    `status`      smallint(4)  NOT NULL DEFAULT '1' COMMENT 'Whether the audit source is online or offline, 0: offline, 1: online' ,
+    `is_deleted`  int(11)               DEFAULT '0' COMMENT 'Whether to delete, 0: not deleted, > 0: deleted',
+    `creator`     varchar(64)  NOT NULL COMMENT 'Creator name',
+    `modifier`    varchar(64)  NOT NULL COMMENT 'Modifier name',
+    `create_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Create time',
+    `modify_time` timestamp    NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'Modify time',
+    `version`     int(11)      NOT NULL DEFAULT '1' COMMENT 'Version number, which will be incremented by 1 after modification',
+    PRIMARY KEY (`id`),
+    UNIQUE KEY `unique_audit_source` (url, `is_deleted`)
+);
 
 -- ----------------------------
 
