@@ -26,11 +26,18 @@ import org.apache.inlong.manager.pojo.stream.InlongStreamBriefInfo;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
 import org.apache.inlong.manager.pojo.stream.InlongStreamPageRequest;
 import org.apache.inlong.manager.pojo.stream.InlongStreamRequest;
+import org.apache.inlong.manager.pojo.user.LoginUserUtils;
 import org.apache.inlong.manager.service.operationlog.OperationLog;
+import org.apache.inlong.manager.service.stream.InlongStreamProcessService;
 import org.apache.inlong.manager.service.stream.InlongStreamService;
-import org.apache.inlong.manager.service.user.LoginUserUtils;
+
+import io.swagger.annotations.Api;
+import io.swagger.annotations.ApiImplicitParam;
+import io.swagger.annotations.ApiImplicitParams;
+import io.swagger.annotations.ApiOperation;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.validation.annotation.Validated;
+import org.springframework.web.bind.annotation.PathVariable;
 import org.springframework.web.bind.annotation.RequestBody;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RequestMethod;
@@ -39,11 +46,6 @@ import org.springframework.web.bind.annotation.RestController;
 
 import java.util.List;
 
-import io.swagger.annotations.Api;
-import io.swagger.annotations.ApiImplicitParam;
-import io.swagger.annotations.ApiImplicitParams;
-import io.swagger.annotations.ApiOperation;
-
 /**
  * Open InLong Stream controller
  */
@@ -54,6 +56,8 @@ public class OpenInLongStreamController {
 
     @Autowired
     private InlongStreamService streamService;
+    @Autowired
+    private InlongStreamProcessService streamProcessOperation;
 
     @RequestMapping(value = "/stream/get", method = RequestMethod.GET)
     @ApiOperation(value = "Get inlong stream")
@@ -68,6 +72,20 @@ public class OpenInLongStreamController {
         return Response.success(streamService.get(groupId, streamId, LoginUserUtils.getLoginUser()));
     }
 
+    @RequestMapping(value = "/stream/getBrief", method = RequestMethod.GET)
+    @ApiOperation(value = "Get inlong stream brief")
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "groupId", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "streamId", dataTypeClass = String.class, required = true)
+    })
+    public Response<InlongStreamBriefInfo> getBrief(@RequestParam String groupId, @RequestParam String streamId) {
+        Preconditions.expectNotBlank(groupId, ErrorCodeEnum.INVALID_PARAMETER, "groupId cannot be blank");
+        Preconditions.expectNotBlank(streamId, ErrorCodeEnum.INVALID_PARAMETER, "streamId cannot be blank");
+        Preconditions.expectNotNull(LoginUserUtils.getLoginUser(), ErrorCodeEnum.LOGIN_USER_EMPTY);
+        String operator = LoginUserUtils.getLoginUser().getName();
+        return Response.success(streamService.getBrief(groupId, streamId, operator));
+    }
+
     @RequestMapping(value = "/stream/list", method = RequestMethod.POST)
     @ApiOperation(value = "List inlong stream briefs by paginating")
     public Response<List<InlongStreamBriefInfo>> listByCondition(@RequestBody InlongStreamPageRequest request) {
@@ -107,4 +125,16 @@ public class OpenInLongStreamController {
         Preconditions.expectNotNull(LoginUserUtils.getLoginUser(), ErrorCodeEnum.LOGIN_USER_EMPTY);
         return Response.success(streamService.delete(groupId, streamId, LoginUserUtils.getLoginUser()));
     }
+
+    @RequestMapping(value = "/stream/startProcess/{groupId}/{streamId}", method = RequestMethod.POST)
+    @ApiOperation(value = "Start inlong stream process")
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "groupId", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "streamId", dataTypeClass = String.class, required = true)
+    })
+    public Response<Boolean> startProcess(@PathVariable String groupId, @PathVariable String streamId,
+            @RequestParam boolean sync) {
+        String operator = LoginUserUtils.getLoginUser().getName();
+        return Response.success(streamProcessOperation.startProcess(groupId, streamId, operator, sync));
+    }
 }
