@@ -13,7 +13,6 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
  */
 
 package org.apache.inlong.sdk.sort.api;
@@ -33,9 +32,12 @@ public class InlongTopicManagerFactory {
             ClientContext context,
             QueryConsumeConfig queryConsumeConfig) {
         switch (type) {
-            case SINGLE_TOPIC: return createSingleTopicManager(context, queryConsumeConfig);
-            case MULTI_TOPIC: return createMultiTopicManager(context, queryConsumeConfig);
-            default: return createSingleTopicManager(context, queryConsumeConfig);
+            case SINGLE_TOPIC:
+                return createSingleTopicManager(context, queryConsumeConfig);
+            case MULTI_TOPIC:
+                return createMultiTopicManager(context, queryConsumeConfig);
+            default:
+                return createSingleTopicManager(context, queryConsumeConfig);
         }
     }
 
